@@ -7,7 +7,7 @@
 #include <wayland-egl.h>
 #include <EGL/egl.h>
 #include <wlm/transform.h>
-#include <wlm/mirror-backends.h>
+#include <wlm/mirror/backends.h>
 
 struct ctx;
 struct output_list_node;
