@@ -5,7 +5,7 @@
 #include <unistd.h>
 #include <wlm/context.h>
 #include <EGL/eglext.h>
-#include <wlm/mirror-backends.h>
+#include <wlm/mirror/backends.h>
 #include <wlm/util.h>
 #include <wlm/proto/linux-dmabuf-unstable-v1.h>
 
@@ -48,13 +48,7 @@ static void on_frame(
     // - screencapture events from backend
     wl_display_roundtrip(ctx->wl.display);
 
-    // render frame, set swap interval to 0 to ensure nonblocking buffer swap
-    wlm_egl_draw_texture(ctx);
-    eglSwapInterval(ctx->egl.display, 0);
-    if (eglSwapBuffers(ctx->egl.display, ctx->egl.surface) != EGL_TRUE) {
-        wlm_log_error("mirror::on_frame(): failed to swap buffers\n");
-        wlm_exit_fail(ctx);
-    }
+    wlm_egl_draw_frame(ctx);
 
     (void)frame_callback;
     (void)msec;
@@ -234,14 +228,24 @@ static size_t specifier_str(ctx_t * ctx, char *dst, int n, specifier_t specifier
 }
 
 static int format_title(ctx_t * ctx, char ** dst, char * fmt) {
+    // guard against mirror not being initialized
+    // for initial setting of the window title
+    int x                    = !ctx->mirror.initialized ? 0 : ctx->mirror.current_region.x;
+    int y                    = !ctx->mirror.initialized ? 0 : ctx->mirror.current_region.y;
+    int width                = !ctx->mirror.initialized ? 0 : ctx->mirror.current_region.width;
+    int height               = !ctx->mirror.initialized ? 0 : ctx->mirror.current_region.height;
+    int target_width         = !ctx->mirror.initialized ? 0 : ctx->mirror.current_target == NULL ? 0 : ctx->mirror.current_target->width;
+    int target_height        = !ctx->mirror.initialized ? 0 : ctx->mirror.current_target == NULL ? 0 : ctx->mirror.current_target->height;
+    const char * target_name = !ctx->mirror.initialized ? "" : ctx->mirror.current_target == NULL ? "" : ctx->mirror.current_target->name;
+
     specifier_t replacements[] = {
-        {"{x}", 'd', {.d = ctx->mirror.current_region.x}},
-        {"{y}", 'd', {.d = ctx->mirror.current_region.y}},
-        {"{width}", 'd', {.d = ctx->mirror.current_region.width}},
-        {"{height}", 'd', {.d = ctx->mirror.current_region.height}},
-        {"{target_width}", 'd', {.d = ctx->mirror.current_target->width}},
-        {"{target_height}", 'd', {.d = ctx->mirror.current_target->height}},
-        {"{target_output}", 's', {.s = ctx->mirror.current_target->name}}
+        {"{x}", 'd', {.d = x}},
+        {"{y}", 'd', {.d = y}},
+        {"{width}", 'd', {.d = width}},
+        {"{height}", 'd', {.d = height}},
+        {"{target_width}", 'd', {.d = target_width}},
+        {"{target_height}", 'd', {.d = target_height}},
+        {"{target_output}", 's', {.s = target_name}}
     };
 
     size_t length = strlen(fmt);
